@@ -46,7 +46,6 @@
 #include "nautilus-dbus-manager.h"
 #include "nautilus-directory-private.h"
 #include "nautilus-file.h"
-#include "nautilus-files-view.h"
 #include "nautilus-file-operations.h"
 #include "nautilus-file-undo-manager.h"
 #include "nautilus-file-utilities.h"
@@ -1221,45 +1220,6 @@ nautilus_application_withdraw_notification (NautilusApplication *self,
     g_application_withdraw_notification (G_APPLICATION (self), notification_id);
 }
 
-static void
-update_previewer_selection (NautilusApplication *self,
-                            NautilusWindow      *window)
-{
-    GtkWindow *gtk_window;
-    NautilusWindowSlot *slot;
-    NautilusView *view;
-    GList *selection;
-
-    gtk_window = gtk_application_get_active_window (GTK_APPLICATION (self));
-    if (!NAUTILUS_IS_WINDOW (gtk_window))
-    {
-        return;
-    }
-
-    if (NAUTILUS_WINDOW (gtk_window) != window)
-    {
-        return;
-    }
-
-    slot = nautilus_window_get_active_slot (window);
-    if (slot == NULL)
-    {
-        return;
-    }
-
-    view = nautilus_window_slot_get_current_view (slot);
-    if (!NAUTILUS_IS_FILES_VIEW (view))
-    {
-        return;
-    }
-
-    selection = nautilus_window_slot_get_selection (slot);
-    if (selection != NULL)
-    {
-        nautilus_files_view_preview_update (NAUTILUS_FILES_VIEW (view), selection);
-    }
-}
-
 static void
 on_application_shutdown (GApplication *application,
                          gpointer      user_data)
@@ -1549,13 +1509,6 @@ on_slot_removed (NautilusWindow      *window,
     g_signal_handlers_disconnect_by_func (slot, on_slot_location_changed, self);
 }
 
-static void
-on_active_selection_changed (NautilusWindow      *window,
-                             NautilusApplication *self)
-{
-    update_previewer_selection (self, window);
-}
-
 static void
 nautilus_application_window_added (GtkApplication *app,
                                    GtkWindow      *window)
@@ -1571,7 +1524,6 @@ nautilus_application_window_added (GtkApplication *app,
         priv->windows = g_list_prepend (priv->windows, window);
         g_signal_connect (window, "slot-added", G_CALLBACK (on_slot_added), app);
         g_signal_connect (window, "slot-removed", G_CALLBACK (on_slot_removed), app);
-        g_signal_connect (window, "active-selection-changed", G_CALLBACK (on_active_selection_changed), app);
     }
 }
 
@@ -1591,7 +1543,6 @@ nautilus_application_window_removed (GtkApplication *app,
         priv->windows = g_list_remove_all (priv->windows, window);
         g_signal_handlers_disconnect_by_func (window, on_slot_added, app);
         g_signal_handlers_disconnect_by_func (window, on_slot_removed, app);
-        g_signal_handlers_disconnect_by_func (window, on_active_selection_changed, app);
     }
 
     /* if this was the last window, close the previewer */
