@@ -533,7 +533,6 @@ nautilus_get_mounted_mount_for_root (GFile *location)
     GMount *mount;
     GMount *result = NULL;
     GFile *root = NULL;
-    GFile *default_location = NULL;
 
     volume_monitor = g_volume_monitor_get ();
     mounts = g_volume_monitor_get_mounts (volume_monitor);
@@ -553,18 +552,9 @@ nautilus_get_mounted_mount_for_root (GFile *location)
             result = g_object_ref (mount);
             break;
         }
-
-        default_location = g_mount_get_default_location (mount);
-        if (!g_file_equal (default_location, root) &&
-            g_file_equal (location, default_location))
-        {
-            result = g_object_ref (mount);
-            break;
-        }
     }
 
     g_clear_object (&root);
-    g_clear_object (&default_location);
     g_list_free_full (mounts, g_object_unref);
 
     return result;
@@ -665,7 +655,9 @@ special_directory_get_icon (GUserDirectory directory,
         ICON_CASE (VIDEOS);
 
         default:
+        {
             return (symbolic) ? g_themed_icon_new (NAUTILUS_ICON_FOLDER) : g_themed_icon_new (NAUTILUS_ICON_FULLCOLOR_FOLDER);
+        }
     }
 
 #undef ICON_CASE
@@ -1495,21 +1487,3 @@ location_settings_search_get_recursive_for_location (GFile *location)
 
     return recursive;
 }
-
-gboolean
-nautilus_file_system_is_remote (const char *file_system)
-{
-    static const gchar * const remote_types[] =
-    {
-        "afp",
-        "google-drive",
-        "sftp",
-        "webdav",
-        "ftp",
-        "nfs",
-        "cifs",
-        NULL
-    };
-
-    return file_system != NULL && g_strv_contains (remote_types, file_system);
-}
