@@ -294,31 +294,6 @@ search_finished_idle (gpointer user_data)
  */
 #define FILENAME_RANK "5.0"
 
-static gchar *
-filter_alnum_strdup (gchar *string)
-{
-    GString *filtered;
-    gchar *c;
-
-    filtered = g_string_new ("");
-    for (c = string; *c; c = g_utf8_next_char (c))
-    {
-        gunichar uc;
-
-        uc = g_utf8_get_char (c);
-        if (g_unichar_isalnum (uc))
-        {
-            g_string_append_unichar (filtered, uc);
-        }
-        else
-        {
-            g_string_append_c (filtered, ' ');
-        }
-    }
-
-    return g_string_free (filtered, FALSE);
-}
-
 static void
 nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
 {
@@ -396,16 +371,13 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
     if (tracker->fts_enabled && *search_text)
     {
         /* Use fts:match only for content search to not lose some filename results due to stop words. */
-        g_autofree gchar *filtered_search_text;
-
-        filtered_search_text = filter_alnum_strdup (search_text);
         g_string_append_printf (sparql,
                                 " { "
                                 " ?content nie:isStoredAs ?file ."
                                 " ?content fts:match \"%s*\" ."
                                 " BIND(fts:rank(?content) AS ?rank1) ."
                                 " } UNION",
-                                filtered_search_text);
+                                search_text);
     }
 
     g_string_append_printf (sparql,
@@ -447,8 +419,8 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
         shifted_end_date = g_date_time_add_days (end_date, 1);
 
         type = nautilus_query_get_search_type (tracker->query);
-        initial_date_format = g_date_time_format (initial_date, "%Y-%m-%dT%H:%M:%S");
-        end_date_format = g_date_time_format (shifted_end_date, "%Y-%m-%dT%H:%M:%S");
+        initial_date_format = g_date_time_format_iso8601 (initial_date);
+        end_date_format = g_date_time_format_iso8601 (shifted_end_date);
 
         g_string_append (sparql, " && ");
 
@@ -573,7 +545,9 @@ nautilus_search_engine_tracker_get_property (GObject    *object,
         break;
 
         default:
+        {
             G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+        }
     }
 }
 
