@@ -14,8 +14,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
-#ifndef NAUTILUS_TOOLBAR_MENU_SECTIONS_H
-#define NAUTILUS_TOOLBAR_MENU_SECTIONS_H
+
+#pragma once
 
 #include <glib.h>
 
@@ -29,6 +29,4 @@ struct _NautilusToolbarMenuSections {
         gboolean   supports_undo_redo;
 };
 
-G_END_DECLS
-
-#endif /* NAUTILUS_TOOLBAR_MENU_SECTIONS_H */
+G_END_DECLS
\ No newline at end of file
